@@ -184,7 +184,10 @@ arguments necessary for the job.")
 
 (defun gnus-get-buffer-name (variable)
   "Returns the buffer name associated with the contents of a variable."
-  (buffer-name (get-buffer (gnus-window-to-buffer-helper variable))))
+  (let ((buf (get-buffer (gnus-window-to-buffer-helper
+			    (cdr (assq variable gnus-window-to-buffer))))))
+    (and buf
+	 (buffer-name buf))))
 
 (defun gnus-picons-buffer-name ()
   (cond ((or (stringp gnus-picons-display-where)
