@@ -1,7 +1,7 @@
 ;;; gnus-uu.el --- extract (uu)encoded files in Gnus
 ;; Copyright (C) 1985,86,87,93,94,95,96,97,98 Free Software Foundation, Inc.
 
-;; Author: Lars Magne Ingebrigtsen <larsi@ifi.uio.no>
+;; Author: Lars Magne Ingebrigtsen <larsi@gnus.org>
 ;; Created: 2 Oct 1993
 ;; Keyword: news
 
@@ -290,7 +290,7 @@ so I simply dropped them."
 
 (defcustom gnus-uu-digest-headers
   '("^Date:" "^From:" "^To:" "^Cc:" "^Subject:" "^Message-ID:" "^Keywords:"
-    "^Summary:" "^References:")
+    "^Summary:" "^References:" "^Content-Type:" "^Content-Transfer-Encoding:")
   "*List of regexps to match headers included in digested messages.
 The headers will be included in the sequence they are matched."
   :group 'gnus-extract
@@ -353,7 +353,9 @@ didn't work, and overwrite existing files.  Otherwise, ask each time."
   "v" gnus-uu-mark-over
   "s" gnus-uu-mark-series
   "r" gnus-uu-mark-region
+  "g" gnus-uu-unmark-region
   "R" gnus-uu-mark-by-regexp
+  "G" gnus-uu-unmark-by-regexp
   "t" gnus-uu-mark-thread
   "T" gnus-uu-unmark-thread
   "a" gnus-uu-mark-all
@@ -843,7 +845,7 @@ didn't work, and overwrite existing files.  Otherwise, ask each time."
 	(when (not (eq in-state 'end))
 	  (setq state (list 'middle))))
       (save-excursion
-	(set-buffer (get-buffer "*gnus-uu-body*"))
+	(set-buffer "*gnus-uu-body*")
 	(goto-char (setq beg (point-max)))
 	(save-excursion
 	  (save-restriction
@@ -885,16 +887,16 @@ didn't work, and overwrite existing files.  Otherwise, ask each time."
 	(when (re-search-forward "^Subject: \\(.*\\)$" nil t)
 	  (setq subj (buffer-substring (match-beginning 1) (match-end 1)))
 	  (save-excursion
-	    (set-buffer (get-buffer "*gnus-uu-pre*"))
+	    (set-buffer "*gnus-uu-pre*")
 	    (insert (format "   %s\n" subj)))))
       (when (or (eq in-state 'last)
 		(eq in-state 'first-and-last))
 	(save-excursion
-	  (set-buffer (get-buffer "*gnus-uu-pre*"))
+	  (set-buffer "*gnus-uu-pre*")
 	  (insert (format "\n\n%s\n\n" (make-string 70 ?-)))
 	  (gnus-write-buffer gnus-uu-saved-article-name))
 	(save-excursion
-	  (set-buffer (get-buffer "*gnus-uu-body*"))
+	  (set-buffer "*gnus-uu-body*")
 	  (goto-char (point-max))
 	  (insert
 	   (concat (setq end-string (format "End of %s Digest" name))
@@ -902,8 +904,8 @@ didn't work, and overwrite existing files.  Otherwise, ask each time."
 	  (insert (concat (make-string (length end-string) ?*) "\n"))
 	  (write-region
 	   (point-min) (point-max) gnus-uu-saved-article-name t))
-	(kill-buffer (get-buffer "*gnus-uu-pre*"))
-	(kill-buffer (get-buffer "*gnus-uu-body*"))
+	(gnus-kill-buffer "*gnus-uu-pre*")
+	(gnus-kill-buffer "*gnus-uu-body*")
 	(push 'end state))
       (if (memq 'begin state)
 	  (cons gnus-uu-saved-article-name state)
